# Generated by Django 3.2.5 on 2021-07-29 07:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drf_actions', '0002_auto_20200618_1044'),
    ]

    operations = [
        migrations.AlterField(
            model_name='actioncontenttype',
            name='content_type',
            field=models.CharField(choices=[('user', 'user'), ('book', 'book'), ('publishbook', 'publishbook')], db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name='actioncontenttype',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='eventjournal',
            name='content_type',
            field=models.CharField(choices=[('user', 'user'), ('book', 'book'), ('publishbook', 'publishbook')], db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name='eventjournal',
            name='data',
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='eventjournal',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='eventjournal',
            name='reason',
            field=models.CharField(choices=[('INSERT', 'INSERT'), ('UPDATE', 'UPDATE'), ('DELETE', 'DELETE')], db_index=True, max_length=30),
        ),
    ]
